package page_votes

import (
	"time"
)

type TemplateIndexVars struct {
	UserUuid          string
	VoterPrivateToken string
	VoterFullname     string
	Questions         []TemplateIndexVarsQuestion
	ExeFingerprint    string
	CodeCommit        string
	CodeDate          time.Time
}

type TemplateIndexVarsQuestion struct {
	Name         string
	Position     int
	Title        string
	Sentence     string
	VoteOpen     bool
	VoteCount    int
	VotedAlready bool
}

const TEMPLATE_INDEX_STR = `<!DOCTYPE html>
<html>
	<head>
		<meta charset="utf-8">
		<title>Vote Électrolab</title>
		<link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/css/bootstrap.min.css" integrity="sha384-Vkoo8x4CGsO3+Hhxv8T/Q5PaXtkKtu6ug5TOeNV6gBiFeWPGFN9MuhOf23Q9Ifjh" crossorigin="anonymous">
	</head>
	<body>
		<nav aria-label="breadcrumb">
		  <ol class="breadcrumb">
		    <li class="breadcrumb-item" aria-current="page"><a href="/?private_token={{.VoterPrivateToken}}">Événements</a></li>
		    <li class="breadcrumb-item active" aria-current="page">AG Électrolab 2020</li>
		  </ol>
		</nav>


		<p>Bienvenue {{.VoterFullname}} !</p>

		<p>Cette page vous est personnelle, et vous permet de voter. Ne transmettez pas ce lien à d'autres personnes !</p>

		<p>Voici la liste des votes du jour :</p>
		<ol>
			{{ range .Questions }}
				<li value="{{.Position}}">

					<a href="/votes/{{.Name}}?private_token={{$.VoterPrivateToken}}">{{.Title}}</a>

					{{ if .VotedAlready }}
						<span class="badge badge-info">a voté</span>
					{{ end }}

					{{ if .VoteOpen }}
						<span class="badge badge-success">en cours</span>
					{{ else if and (gt .VoteCount 0) (not .VotedAlready) }}
						<span class="badge badge-danger">clos</span>
					{{ end }}
				</li>
			{{ end }}
		</ol>
	</body>
</html>
`
